#!/usr/bin/env python
# -*- coding: utf-8 -*-

# author: Pocholo
# date: 4/6/22

# Comments directed to http://gimpchat.com

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.


from gimpfu import *
import os,sys,time
import math
import string
from array import array
import gettext
gettext.install("gimp20", gimp.locale_directory, unicode=True)

def pm_create_wall_photo_strips(filename):

    #Initiates the temporary state
    pdb.gimp_context_push()
    pdb.gimp_context_set_defaults()

    #Variables
    width = 2000
    height = 1400
    
    #Create the background
    img = pdb.gimp_image_new(width, height, RGB)
    backLayer = pdb.gimp_layer_new(img, width, height, RGBA_IMAGE, "Background", 100, LAYER_MODE_NORMAL)
    pdb.gimp_image_insert_layer(img, backLayer, None, 0)
    pdb.gimp_context_set_foreground("Black")
    pdb.gimp_drawable_fill(backLayer, FILL_FOREGROUND)
    
    pdb.gimp_display_new(img)

    #Open a photo
    imagLayer = pdb.gimp_file_load_layer(img, filename)
    pdb.gimp_layer_add_alpha(imagLayer)
    pdb.gimp_image_insert_layer(img, imagLayer, None, 0)
    
    #Resize image
    pdb.gimp_layer_scale(imagLayer, 1580, 1100, TRUE) 
    
    #Center the image to the canvas and merge 
    imagLayer.set_offsets((img.width - imagLayer.width) / 2, (img.height - imagLayer.height) / 2)
    
    pdb.gimp_image_set_active_layer(img, imagLayer)
    pdb.gimp_item_set_name(imagLayer, "Image") 
      
    #Add guides
    column = 19
    double_G = 0
    non_empty, x1, y1, x2, y2 = pdb.gimp_selection_bounds(img)
    if column > 0:
        size = (pdb.gimp_image_width(img) - (double_G * (column + 1))) / column
        for count in range(column + 1):
            if count == 0:
                guide = pdb.gimp_image_add_vguide(img, double_G)
            elif count > 0 and count < column:
                guide = pdb.gimp_image_add_vguide(img, (size + double_G) * count + double_G)
                guide = pdb.gimp_image_add_vguide(img, (size + double_G) * count)
            else:
                guide = pdb.gimp_image_add_vguide(img, (size + double_G) * count)
   
    #guillotine
    pdb.python_fu_ofn_guillotine_layer(img, imagLayer)
    topLayer = pdb.gimp_image_get_layer_by_name(img, "Image @ (1785,0)")
    pdb.gimp_image_remove_layer(img, topLayer)
    pdb.gimp_item_set_visible(backLayer, FALSE)
    
    applyvisible = 0
    prefix = 0
    applylayers = []
    counter = 0
    for layer in img.layers:
        counter += 1
        if (applyvisible == 1) or (layer.visible != 0):
            applylayers.append([layer,counter])                
    for applylayer in applylayers:
        applylayer[0].name = "Strip #1"        
       
    #Reverse visible layers
    layerlist = img.layers
    processlist=[]
    emptycheck =[]   
    for i in range(len(layerlist)):
        visible = pdb.gimp_item_get_visible(layerlist[i])
        if visible:
            processlist.append(layerlist[i])
    count = 0
    for i in processlist:
        pdb.gimp_image_raise_item_to_top(img,i)
        count+=1

    #Layer to image size all layers
    img = img = gimp.image_list()[0] 
    for layer in img.layers: 
        layer.resize_to_image_size()
        
    #Offsets fist half
    Layer_1 = pdb.gimp_image_get_layer_by_name(img, "Strip #1")
    pdb.gimp_layer_set_offsets(Layer_1, 140, 10)
    Layer_2 = pdb.gimp_image_get_layer_by_name(img, "Strip #2")
    pdb.gimp_layer_set_offsets(Layer_2, 120, -30)
    Layer_3 = pdb.gimp_image_get_layer_by_name(img, "Strip #3")
    pdb.gimp_layer_set_offsets(Layer_3, 100, 40)
    Layer_4 = pdb.gimp_image_get_layer_by_name(img, "Strip #4")
    pdb.gimp_layer_set_offsets(Layer_4, 80, -20)
    Layer_5 = pdb.gimp_image_get_layer_by_name(img, "Strip #5")
    pdb.gimp_layer_set_offsets(Layer_5, 60, 30)
    Layer_6 = pdb.gimp_image_get_layer_by_name(img, "Strip #6")
    pdb.gimp_layer_set_offsets(Layer_6, 40, -40)
    Layer_7 = pdb.gimp_image_get_layer_by_name(img, "Strip #7")
    pdb.gimp_layer_set_offsets(Layer_7, 20, 20)
    #Offsets fist half
    Layer_15 = pdb.gimp_image_get_layer_by_name(img, "Strip #15")
    pdb.gimp_layer_set_offsets(Layer_15, -140, 40)
    Layer_14 = pdb.gimp_image_get_layer_by_name(img, "Strip #14")
    pdb.gimp_layer_set_offsets(Layer_14, -120, -30)
    Layer_13 = pdb.gimp_image_get_layer_by_name(img, "Strip #13")
    pdb.gimp_layer_set_offsets(Layer_13, -100, 10)
    Layer_12 = pdb.gimp_image_get_layer_by_name(img, "Strip #12")
    pdb.gimp_layer_set_offsets(Layer_12, -80, -20)
    Layer_11 = pdb.gimp_image_get_layer_by_name(img, "Strip #11")
    pdb.gimp_layer_set_offsets(Layer_11, -60, 30)
    Layer_10 = pdb.gimp_image_get_layer_by_name(img, "Strip #10")
    pdb.gimp_layer_set_offsets(Layer_10, -40, -30)
    Layer_9 = pdb.gimp_image_get_layer_by_name(img, "Strip #9")
    pdb.gimp_layer_set_offsets(Layer_9, -20, 10)

    #Layer to image size all layers
    img = img = gimp.image_list()[0] 
    for layer in img.layers: 
        layer.resize_to_image_size()
    
    #Remove all guides
    pdb.script_fu_guides_remove(img, imagLayer)
    
    #Crea a new layer from visible
    pdb.gimp_item_set_visible(backLayer, FALSE)
    new_layer = pdb.gimp_layer_new_from_visible(img, img, "Pre-bevel")
    pdb.gimp_layer_add_alpha(new_layer)
    pdb.gimp_image_insert_layer(img, new_layer, None, 0)
    
    #Copy visible
    bevLayer = pdb.gimp_layer_new_from_drawable(new_layer, img)
    pdb.gimp_image_insert_layer(img, bevLayer, None, 0)
    pdb.gimp_layer_set_mode(bevLayer, LAYER_MODE_SCREEN)
    pdb.gimp_item_set_name(bevLayer, "Beveled")
    pdb.gimp_item_set_visible(backLayer, TRUE)
    
    #Add bevel
    pdb.gimp_image_select_item(img, CHANNEL_OP_REPLACE, new_layer)
    pdb.gimp_context_set_foreground((128, 128, 128))
    pdb.gimp_edit_bucket_fill(bevLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
    pdb.gimp_selection_shrink(img, 5)
    pdb.gimp_drawable_edit_clear(bevLayer)
    pdb.gimp_image_select_item(img, CHANNEL_OP_REPLACE, new_layer)
    pdb.plug_in_gauss(img, bevLayer, 20, 20, 1)   #method=1
    pdb.gimp_selection_none(img)
   
    pdb.gimp_context_pop()
     
register(
    "pm_create_wall_photo_strips",
    "Creates a photo strips from image",
    "Creates a wall photo strips frames from image",
    "Pocholo M",
    "Pocholo M",
    "2022",
    "Wall Photo Strips",
    "RGB*, GRAY",
    [
    (PF_FILENAME, "filename", "Image:", None),
    ],
    [],
    pm_create_wall_photo_strips, menu="<Image>/File/Create/Create Photo Strips",
    domain=("gimp20", gimp.locale_directory))
main()			   